package cn.com.ty.lift.system.region.controller;

import cn.com.ty.lift.system.region.dao.entity.Region;
import cn.com.ty.lift.system.region.dao.entity.model.RegionReq;
import cn.com.ty.lift.system.region.service.impl.RegionServiceImpl;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 区域表 前端控制器
 * </p>
 *
 * @author wang-hai-cheng
 * @since 2019-12-09
 */
@AllArgsConstructor
@RestController
@RequestMapping("/region")
public class RegionController {
    private final RegionServiceImpl regionService;

    @PostMapping("/list")
    public RestResponse list(@RequestBody RegionReq regionReq) {
        return RestResponse.ok(regionService.page(new Page<>(regionReq.getPageNum(), regionReq.getPageSize())));
    }

    @PostMapping("/add")
    public RestResponse add(@RequestBody Region region) {
        if (regionService.save(region)) {
            return RestResponse.ok(null, "1", "新增成功");
        }
        return RestResponse.ok(null, "0", "新增失败");
    }

    @PostMapping("/delete")
    public RestResponse delete(@RequestParam Integer id) {
        if (regionService.removeById(id)) {
            return RestResponse.ok(null, "1", "删除成功");
        }
        return RestResponse.ok(null, "0", "删除失败");
    }

    @PostMapping("/update")
    public RestResponse update(@RequestBody Region region) {
        if (regionService.updateById(region)) {
            return RestResponse.ok(null, "1", "修改成功");
        }
        return RestResponse.ok(null, "0", "修改失败");
    }

    @GetMapping
    public RestResponse get(@RequestParam Integer id) {
        Region byId = regionService.getById(id);
        if (null == byId) {
            return RestResponse.ok(null, "9", "未找到");
        }
        return RestResponse.ok(byId, "1", "查询成功");
    }

    @PostMapping("/project/regions")
    public RestResponse project(@RequestBody Region region) {
        List<Region> regions = regionService.list(new QueryWrapper<Region>()
                .select("id", "province_code", "city_code", "area_code", "area_name")
                .eq("mt_company_id", region.getMtCompanyId()));
        if (regions.isEmpty()) {
            return RestResponse.ok(null, "9", "无数据");
        }
        return RestResponse.ok(regions, "1", "查询成功");
    }
}